@@ -1,5 +1,5 @@
 package Spork::Shlomify::Slides;
-$Spork::Shlomify::Slides::VERSION = '0.0402';
+$Spork::Shlomify::Slides::VERSION = '0.0403';
 use strict;
 use warnings;
 use Spork;
@@ -59,7 +59,7 @@ Spork::Shlomif::Slides - the slides generation class for Spork::Shlomify
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 FUNCTIONS
 
@@ -108,14 +108,6 @@ L<https://metacpan.org/release/Spork-Shlomify>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Spork-Shlomify>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -124,14 +116,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Spork-Shlomify>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Spork-Shlomify>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
